@@ -273,7 +273,7 @@ compare_ts(struct timespec ts1,
  * Returns true if THE_TIME is 
  * COMP_GT: after the specified time
  * COMP_LT: before the specified time
- * COMP_EQ: less than WINDOW seconds after the specified time.
+ * COMP_EQ: after the specified time but by not more than WINDOW seconds.
  */
 static boolean
 pred_timewindow(struct timespec ts, struct predicate const *pred_ptr, int window)
@@ -288,8 +288,21 @@ pred_timewindow(struct timespec ts, struct predicate const *pred_ptr, int window
       
     case COMP_EQ:
       {
+	/* consider "find . -mtime 0".
+	 * 
+	 * Here, the origin is exactly 86400 seconds before the start 
+	 * of the program (since -daystart was not specified).   This 
+	 * function will be called with window=86400 and 
+	 * pred_ptr->args.reftime.ts as the origin.  Hence a file 
+	 * created the instant the program starts will show a time 
+	 * difference (value of delta) of 86400.   Similarly, a file 
+	 * created exactly 24h ago would be the newest file which was 
+	 * _not_ created today.   So, if delta is 0.0, the file 
+	 * was not created today.  If the delta is 86400, the file 
+	 * was created this instant.
+	 */
 	double delta = ts_difference(ts, pred_ptr->args.reftime.ts);
-	return (delta >= 0.0 && delta < window);
+	return (delta > 0.0 && delta <= window);
       }
     }
   assert (0);
@@ -408,12 +421,7 @@ pred_delete (const char *pathname, struct stat *stat_buf, struct predicate *pred
 		}
 	    }
 	}
-      error (0, errno, _("cannot delete %s"
-			 /* TRANSLATORS: the argument is either a
-			  * file or a directory, but we do not know which.
-			  * Mail bug-findutils@gnu.org if you cannot correctly 
-			  * translate the string without knowing.
-			  */),
+      error (0, errno, _("cannot delete %s"),
 	     safely_quote_err_filename(0, pathname));
       /* Previously I had believed that having the -delete action
        * return false provided the user with control over whether an
@@ -1416,11 +1424,7 @@ is_ok(const char *program, const char *arg)
      This standard does not have requirements for locales other than POSIX
   */
   /* XXX: printing UNTRUSTED data here. */
-  fprintf (stderr, _("< %s ... %s > ? "
-		     /* TRANSLATORS: we would like, if possible, the final non-blank 
-		      * character of this string to be '?', but it is not 
-		      * wholly essential. */
-		     ), program, arg);
+  fprintf (stderr, _("< %s ... %s > ? "), program, arg);
   fflush (stderr);
   return yesno();
 }
@@ -1978,7 +1982,7 @@ launch (const struct buildcmd_control *ctl,
   
   if (WIFSIGNALED (wait_status))
     {
-      error (0, 0, _("%1$s terminated by signal %2$d"),
+      error (0, 0, _("%s terminated by signal %d"),
 	     quotearg_n_style(0, options.err_quoting_style,
 			      buildstate->cmd_argv[0]),
 	     WTERMSIG (wait_status));
