@@ -1,25 +1,21 @@
 /* listfile.c -- display a long listing of a file
    Copyright (C) 1991, 1993, 2000, 2004, 2005, 2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#if HAVE_CONFIG_H
-# include <config.h>
-#endif
+#include <config.h>
 
 #include <alloca.h>
 
@@ -42,6 +38,7 @@
 #include "error.h"
 #include "filemode.h"
 #include "dircallback.h"
+#include "idcache.h"
 
 #include "listfile.h"
 
@@ -92,7 +89,7 @@
 #ifndef S_ISBLK
 #define S_ISBLK(m) (((m) & S_IFMT) == S_IFBLK)
 #endif
-#if defined(S_IFLNK) && !defined(S_ISLNK)
+#if defined S_IFLNK && !defined S_ISLNK
 #define S_ISLNK(m) (((m) & S_IFMT) == S_IFLNK)
 #endif
 
@@ -112,7 +109,7 @@
    ST_NBLOCKSIZE: Size of blocks used when calculating ST_NBLOCKS.  */
 #ifndef HAVE_STRUCT_STAT_ST_BLOCKS
 # define ST_BLKSIZE(statbuf) DEV_BSIZE
-# if defined(_POSIX_SOURCE) || !defined(BSIZE) /* fileblocks.c uses BSIZE.  */
+# if defined _POSIX_SOURCE || !defined BSIZE /* fileblocks.c uses BSIZE.  */
 #  define ST_NBLOCKS(statbuf) \
   (S_ISREG ((statbuf).st_mode) \
    || S_ISDIR ((statbuf).st_mode) \
@@ -127,16 +124,16 @@
 /* Some systems, like Sequents, return st_blksize of 0 on pipes. */
 # define ST_BLKSIZE(statbuf) ((statbuf).st_blksize > 0 \
 			       ? (statbuf).st_blksize : DEV_BSIZE)
-# if defined(hpux) || defined(__hpux__) || defined(__hpux)
+# if defined hpux || defined __hpux__ || defined __hpux
 /* HP-UX counts st_blocks in 1024-byte units.
    This loses when mixing HP-UX and BSD filesystems with NFS.  */
 #  define ST_NBLOCKSIZE 1024
 # else /* !hpux */
-#  if defined(_AIX) && defined(_I386)
+#  if defined _AIX && defined _I386
 /* AIX PS/2 counts st_blocks in 4K units.  */
 #   define ST_NBLOCKSIZE (4 * 1024)
 #  else /* not AIX PS/2 */
-#   if defined(_CRAY)
+#   if defined _CRAY
 #    define ST_NBLOCKS(statbuf) \
   (S_ISREG ((statbuf).st_mode) \
    || S_ISDIR ((statbuf).st_mode) \
@@ -169,12 +166,8 @@
 
 static void print_name (register const char *p, FILE *stream, int literal_control_chars);
 
-extern char * getgroup (gid_t gid);
-extern char * getuser (uid_t uid);
 
-
-
-size_t 
+size_t
 file_blocksize(const struct stat *p)
 {
   return ST_NBLOCKSIZE;
@@ -200,7 +193,7 @@ list_file (const char *name,
 	   int literal_control_chars,
 	   FILE *stream)
 {
-  char modebuf[11];
+  char modebuf[12];
   struct tm const *when_local;
   char const *user_name;
   char const *group_name;
@@ -212,7 +205,6 @@ list_file (const char *name,
 #else
   strmode (statp->st_mode, modebuf);
 #endif
-  modebuf[10] = '\0';
 
   fprintf (stream, "%6s ",
 	   human_readable ((uintmax_t) statp->st_ino, hbuf,
@@ -225,9 +217,9 @@ list_file (const char *name,
 			   ST_NBLOCKSIZE, output_block_size));
 
 
-  /* The space between the mode and the number of links is the POSIX
-     "optional alternate access method flag".  */
-  fprintf (stream, "%s %3lu ", modebuf, (unsigned long) statp->st_nlink);
+  /* modebuf includes the space between the mode and the number of links,
+     as the POSIX "optional alternate access method flag".  */
+  fprintf (stream, "%s%3lu ", modebuf, (unsigned long) statp->st_nlink);
 
   user_name = getuser (statp->st_uid);
   if (user_name)
@@ -277,7 +269,7 @@ list_file (const char *name,
 	 : "%b %e  %Y");
 
       while (!strftime (buf, bufsize, fmt, when_local))
-	buf = (char *) alloca (bufsize *= 2);
+	buf = alloca (bufsize *= 2);
 
       fprintf (stream, "%s ", buf);
     }
@@ -397,7 +389,7 @@ get_link_name (const char *name, char *relname)
      mount points with some automounters.
      So allocate a pessimistic PATH_MAX + 1 bytes.  */
 #define LINK_BUF PATH_MAX
-  linkname = (char *) xmalloc (LINK_BUF + 1);
+  linkname = xmalloc (LINK_BUF + 1);
   linklen = readlink (relname, linkname, LINK_BUF);
   if (linklen < 0)
     {
