@@ -911,9 +911,9 @@ print_stats(int argc, size_t database_file_size)
    */
   printf(_("File names have a cumulative length of %1$s bytes.\n"
 	   "Of those file names,\n"
-	   "\n\t%2$s contain whitespace, "
-	   "\n\t%3$s contain newline characters, "
-	   "\n\tand %4$s contain characters with the high bit set.\n"),
+	   "\n\t%s contain whitespace, "
+	   "\n\t%s contain newline characters, "
+	   "\n\tand %s contain characters with the high bit set.\n"),
 	 human_readable (statistics.total_filename_length,  hbuf1, human_ceiling, 1, 1),
 	 human_readable (statistics.whitespace_count,       hbuf2, human_ceiling, 1, 1),
 	 human_readable (statistics.newline_count,          hbuf3, human_ceiling, 1, 1),
@@ -998,8 +998,8 @@ looking_at_slocate_locatedb (const char *filename,
 		   * We don't know how to handle those.
 		   */
 		  error(0, 0,
-			_("locate database %1$s looks like an slocate "
-			  "database but it seems to have security level %2$c, "
+			_("locate database %s looks like an slocate "
+			  "database but it seems to have security level %c, "
 			  "which GNU findutils does not currently support"),
 			quotearg_n_style(0, locale_quoting_style, filename),
 			data[1]);
@@ -1129,7 +1129,7 @@ search_one_database (int argc,
 	   * so do nothing further 
 	   */
 	  error(0, 0,
-		_("%1$s is an slocate database of unsupported security level %2$d; skipping it."),
+		_("%s is an slocate database of unsupported security level %d; skipping it."),
 		quotearg_n_style(0, locale_quoting_style, procdata.dbfile),
 		slocate_seclevel);
 	  return 0;
@@ -1347,7 +1347,7 @@ search_one_database (int argc,
 
   if (stats)
     {
-      printf(_("Database %1$s is in the %2$s format.\n"),
+      printf(_("Database %s is in the %s format.\n"),
 	     procdata.dbfile,
 	     format_name);
     }
@@ -1864,12 +1864,10 @@ dolocate (int argc, char **argv, int secure_db_fd)
 		  /* For example:
 		     warning: database `fred' is more than 8 days old (actual age is 10 days)*/
 		  error (0, 0,
-			 _("warning: database %1$s is more than %2$d %3$s old (actual age is %4$.1f %5$s)"),
+			 _("warning: database %s is more than %d %s old (actual age is %.1f %s)"),
 			 quotearg_n_style(0,  locale_quoting_style, e), 
-			 warn_number_units,
-			 _(warn_name_units),
-			 (age/(double)SECONDS_PER_UNIT),
-			 _(warn_name_units));
+			 warn_number_units,              _(warn_name_units),
+			 (age/(double)SECONDS_PER_UNIT), _(warn_name_units));
 		}
 	    }
 	}
